<?php

require_once 'lib/hashed_array.php';
require_once 'lib/tv/abstract_tv.php';
require_once 'lib/tv/default_epg_item.php';

require_once 'tv_channel.php';

class MyPlugINTv extends AbstractTv
{
	public $cookie = array();

	public function __construct($session)
	{
		parent::__construct(
			AbstractTv::MODE_CHANNELS_N_TO_M,
			MyPlugIN_Config::TV_FAVORITES_SUPPORTED,
			true);
		$this->session = $session;
	}

	public function get_fav_icon_url()
	{
		return 'plugin_file://icons/genres/fav.png';
	}
	public function get_all_icon_url()
	{
		return 'plugin_file://icons/genres/all.png';
	}

	public function newload(&$plugin_cookies)
	{
		if(is_null($this->channels) && is_null($this->groups))
			$this->load_channels($plugin_cookies);
	}

	/**
	 * @param $plugin_cookies
	 */
	protected function load_channels(&$plugin_cookies)
	{
		$this->session->check_login($plugin_cookies);
		$this->channels = new HashedArray();
		$this->groups = new HashedArray();
		$group_tmp = null;
		$buffer = isset($plugin_cookies->buf_time) ? $plugin_cookies->buf_time : 0;
		$hide_category_items = isset($plugin_cookies->hide_category_items) ? $plugin_cookies->hide_category_items : '';
		$hide_items = isset($plugin_cookies->hide_items) ? $plugin_cookies->hide_items : '';
		$hided_channels = isset($plugin_cookies->hided_channels) ? $plugin_cookies->hided_channels : 'no';
		if ($this->is_favorites_supported())
		{
			$this->groups->put( new FavoritesGroup(	$this,
											'__favorites',
											'Избранные',
											$this->get_fav_icon_url()));
		}		
		$this->groups->put( new AllChannelsGroup(	$this,
										'Все каналы',
										$this->get_all_icon_url()));		
		$category = $this->session->get_group_tv();		
		foreach ($category->results as $tv_category)
		{
			$cha_tv = $this->session->get_group_tv_channel($tv_category->id);		
			if(!empty($cha_tv->results) && !ListUtil::is_in_list($hide_category_items, $tv_category->number))
			{
				#hd_print($tv_category->id);
				$this->groups->put( new DefaultGroup(
											$tv_category->number,
											strval($tv_category->title),
											'plugin_file://icons/genres/'.$tv_category->id.'.png'));
				
				foreach ($cha_tv->results as $channels)
				{
					if(isset($channels->id))
						$logo = MyPlugIN_Config::API_URL . '/logo/' . $channels->id . '.png';
					else
					{
						$logo = MyPlugIN_Config::API_URL."/stalker_portal/misc/logos/dummy.png";
						hd_print("channel don't have logo: ".$channels->id);
					}
					$stalker_channel = new MyPlugIN_Channel(
													intval($channels->id),
													strval($channels->name),
													strval($logo),
													"",
													intval($channels->archive_range) / 24,
													4,
													$buffer,
													intval($channels->censored),
													intval($channels->archive),
													"");
					########hide########
					if($hided_channels == 'no')
					{
						$ch = strval($channels->id);
						$t = ListUtil::is_in_list($hide_items, $ch);
						if ($ch == $t) continue;
					}
					
					####################
					$this->channels->put($stalker_channel);
					$group = $this->groups->get($tv_category->number);		
					// Link group and channel.
					$stalker_channel->add_group($group);
					$group->add_channel($stalker_channel);
				}
			}
		}
	}

	public function get_tv_playback_url($channel_id,$archive_ts,$protect_code,&$plugin_cookies)
	{
		$this->ensure_channels_loaded($plugin_cookies);
		$this->session->check_login($plugin_cookies);	
		$account_settings = $this->session->get_account_settings();
		$pass_sex = $account_settings->results->parent_password;
		$nado = $this->get_channel($channel_id)->is_protected();
		
		if($nado)
		{
			if ($protect_code != $pass_sex)
				$url = 'protected';
			else
				$url = $this->session->get_url($channel_id,$archive_ts,$protect_code,&$plugin_cookies);
		}
		else
			$url = $this->session->get_url($channel_id,$archive_ts,$protect_code,&$plugin_cookies);
		return $url;
	}

	public function get_day_epg_iterator($channel_id, $day_start_ts, &$plugin_cookies)
	{
		$epg = array();
		$epg_shift = isset($plugin_cookies->epg_shift) ? $plugin_cookies->epg_shift : 0;		
		$xml = $this->session->get_stalker_epg($day_start_ts,$channel_id,$this->cookie,&$plugin_cookies);
		if ($xml->status !== 'OK')
		{
			$epg[] =
			new DefaultEpgItem(
			"ТВ Программа отсутствует!",
			"",
			"",
			0);
		}
		else
		{
			foreach ($xml->results as $epg_item)
			{
				#print_r($epg_item);
				$epg[] =
				new DefaultEpgItem(
				strval($epg_item->name),
				strval($epg_item->id),
				intval($epg_item->start),
				intval($epg_item->end));		
			}
		}		
		return new EpgIterator(
		$epg,
		$day_start_ts,
		$day_start_ts + 86400 * 7);
	}

	public function get_archive(MediaURL $media_url)
	{ 
		return $this->session->get_archive();
	}
	
    public function add_special_groups(&$items)
    {
        array_push($items,
            array
            (
                PluginRegularFolderItem::media_url =>
                    MediaURL::encode(
                        array
                        (
                            'screen_id' => MyPlugIN_VodCategoryListScreen::ID,
                            'name' => 'VOD')),
                PluginRegularFolderItem::caption => 'Медиатека',
                PluginRegularFolderItem::view_item_params => array
                (ViewItemParams::icon_path =>"plugin_file://icons/vod.png")));
    }
	
	
	
	
}

?>
